==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d4/d48/newgrf_8h.js <==
var newgrf_8h =
[
    [ "CanalProperties", "d7/df3/structCanalProperties.html", "d7/df3/structCanalProperties" ],
    [ "GRFLabel", "dc/d6c/structGRFLabel.html", "dc/d6c/structGRFLabel" ],
    [ "GRFFile", "d1/d53/structGRFFile.html", "d1/d53/structGRFFile" ],
    [ "GRFLoadedFeatures", "d5/dd5/structGRFLoadedFeatures.html", "d5/dd5/structGRFLoadedFeatures" ],
    [ "CanalFeature", "d4/d48/newgrf_8h.html#adbb765b5f83e5e13ed31c76be18fd933", [
      [ "CF_WATERSLOPE", "d4/d48/newgrf_8h.html#adbb765b5f83e5e13ed31c76be18fd933af8eaf6e247f3d19ab88618fbbd63dbee", null ],
      [ "CF_LOCKS", "d4/d48/newgrf_8h.html#adbb765b5f83e5e13ed31c76be18fd933a5a57741888ffe2d2a40e15a5a6b96477", null ],
      [ "CF_DIKES", "d4/d48/newgrf_8h.html#adbb765b5f83e5e13ed31c76be18fd933a0963ed28a64ef7a22f8c06bacf3a0eb0", null ],
      [ "CF_ICON", "d4/d48/newgrf_8h.html#adbb765b5f83e5e13ed31c76be18fd933ace384691a568d66d0907d03fb6c77873", null ],
      [ "CF_DOCKS", "d4/d48/newgrf_8h.html#adbb765b5f83e5e13ed31c76be18fd933afa2d4cb8f1932cb5557504bad2810804", null ],
      [ "CF_RIVER_SLOPE", "d4/d48/newgrf_8h.html#adbb765b5f83e5e13ed31c76be18fd933a5d203eb15f1dce708cbe72b100802e0d", null ],
      [ "CF_RIVER_EDGE", "d4/d48/newgrf_8h.html#adbb765b5f83e5e13ed31c76be18fd933aa7819b842480d4eb2de4853c8c1b692b", null ],
      [ "CF_RIVER_GUI", "d4/d48/newgrf_8h.html#adbb765b5f83e5e13ed31c76be18fd933a0e55e0320e2146f943a6296689eb4628", null ],
      [ "CF_BUOY", "d4/d48/newgrf_8h.html#adbb765b5f83e5e13ed31c76be18fd933a2d90ce24edcf0ef51a42afb1a21b578f", null ],
      [ "CF_END", "d4/d48/newgrf_8h.html#adbb765b5f83e5e13ed31c76be18fd933a095e0dd0731658557edfd9261560f541", null ]
    ] ],
    [ "GrfLoadingStage", "d4/d48/newgrf_8h.html#ae7d82234c394971067394d5d3516dfc8", [
      [ "GLS_FILESCAN", "d4/d48/newgrf_8h.html#ae7d82234c394971067394d5d3516dfc8a3f4b9e3a44fb1f1c87126a42f2d9ff2b", null ],
      [ "GLS_SAFETYSCAN", "d4/d48/newgrf_8h.html#ae7d82234c394971067394d5d3516dfc8af52a20b0eee00a99d034825409081c0c", null ],
      [ "GLS_LABELSCAN", "d4/d48/newgrf_8h.html#ae7d82234c394971067394d5d3516dfc8abf73201c5e2a615fbeed18259cd07ce8", null ],
      [ "GLS_INIT", "d4/d48/newgrf_8h.html#ae7d82234c394971067394d5d3516dfc8a80ece95b1919a116e75f31e1a4fc5e60", null ],
      [ "GLS_RESERVE", "d4/d48/newgrf_8h.html#ae7d82234c394971067394d5d3516dfc8a73d61f963e5cbd790f8bbe8ab3bbba8f", null ],
      [ "GLS_ACTIVATION", "d4/d48/newgrf_8h.html#ae7d82234c394971067394d5d3516dfc8aedf7b2b921e815966b128e51608fd33e", null ],
      [ "GLS_END", "d4/d48/newgrf_8h.html#ae7d82234c394971067394d5d3516dfc8a7cf74d6696946f982bbfbcb6bba71b5d", null ]
    ] ],
    [ "GrfMiscBit", "d4/d48/newgrf_8h.html#a7f005440c7ec2678300d41df0eb71f8f", [
      [ "GMB_DESERT_TREES_FIELDS", "d4/d48/newgrf_8h.html#a7f005440c7ec2678300d41df0eb71f8faccdf068d8e2d46f19bda7f1c8b85d084", null ],
      [ "GMB_DESERT_PAVED_ROADS", "d4/d48/newgrf_8h.html#a7f005440c7ec2678300d41df0eb71f8fa3f6c7a31f7d335390451af69de8350b6", null ],
      [ "GMB_FIELD_BOUNDING_BOX", "d4/d48/newgrf_8h.html#a7f005440c7ec2678300d41df0eb71f8fa9a19cd99c699437f375ed1479fe4fa35", null ],
      [ "GMB_TRAIN_WIDTH_32_PIXELS", "d4/d48/newgrf_8h.html#a7f005440c7ec2678300d41df0eb71f8fae21984bb6385d9e64c97b1419ace4d57", null ],
      [ "GMB_AMBIENT_SOUND_CALLBACK", "d4/d48/newgrf_8h.html#a7f005440c7ec2678300d41df0eb71f8fa519e147f5a0d92d67d11c06281979463", null ],
      [ "GMB_CATENARY_ON_3RD_TRACK", "d4/d48/newgrf_8h.html#a7f005440c7ec2678300d41df0eb71f8fa9bad51a17380a81999d9c8b70c858b5f", null ],
      [ "GMB_SECOND_ROCKY_TILE_SET", "d4/d48/newgrf_8h.html#a7f005440c7ec2678300d41df0eb71f8fa822d70038b1d7ccefea5af8f74e06695", null ]
    ] ],
    [ "GrfSpecFeature", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71fed", [
      [ "GSF_TRAINS", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71feda26df69171fb034ed3cf892bc4daa8fac", null ],
      [ "GSF_ROADVEHICLES", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71feda755d310e70804a736e47453e258f7c0e", null ],
      [ "GSF_SHIPS", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71feda7076c36d72deb69536d404605a1cac67", null ],
      [ "GSF_AIRCRAFT", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71fedaa33d020de9a1390c5553f74a912277b9", null ],
      [ "GSF_STATIONS", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71feda0609a53393335363693c183b3375966d", null ],
      [ "GSF_CANALS", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71feda69e99804291f7504d05e218d4268d9c9", null ],
      [ "GSF_BRIDGES", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71feda4f63e02c0e3e15630447e928881e7b41", null ],
      [ "GSF_HOUSES", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71feda06011824707bd88351a7471eaefb5cbb", null ],
      [ "GSF_GLOBALVAR", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71feda04eeda295e3b6b7c8ba8a861b06044df", null ],
      [ "GSF_INDUSTRYTILES", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71fedaa6adfbbf866f6f92622eddca16306507", null ],
      [ "GSF_INDUSTRIES", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71fedac1d6d9cf5b9176a997ac2a4641caabf1", null ],
      [ "GSF_CARGOES", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71feda5b78c9caf284955b01f03b7cb4c53320", null ],
      [ "GSF_SOUNDFX", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71fedaab0857a902a10d5b93bc77923adc09a0", null ],
      [ "GSF_AIRPORTS", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71feda42af615d90c798d00f84af49c8ae5309", null ],
      [ "GSF_SIGNALS", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71fedaaabc57449adf973e52a19ed04649bf01", null ],
      [ "GSF_OBJECTS", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71feda50f206bf98e3d7058965458bac7a27ad", null ],
      [ "GSF_RAILTYPES", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71fedaee99c5670b3b404fd8f94b30a731fef6", null ],
      [ "GSF_AIRPORTTILES", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71feda4bf75eab552b66ea5e534d043797b180", null ],
      [ "GSF_END", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71feda2ac469a0cb96ec26a646f017a3151119", null ],
      [ "GSF_FAKE_TOWNS", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71feda2e5f12fce01460a62a2060acc3817ded", null ],
      [ "GSF_FAKE_END", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71fedab4f65c0c10aa7156c5b1b70d0d836173", null ],
      [ "GSF_INVALID", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71fedab1911de5bda9645ec61bbe15b46b7d49", null ]
    ] ],
    [ "ShoreReplacement", "d4/d48/newgrf_8h.html#aae7e5011a054dadf96117e249a32e35e", [
      [ "SHORE_REPLACE_NONE", "d4/d48/newgrf_8h.html#aae7e5011a054dadf96117e249a32e35ea85983d6b8e72b2318260af67ba75a5f2", null ],
      [ "SHORE_REPLACE_ACTION_5", "d4/d48/newgrf_8h.html#aae7e5011a054dadf96117e249a32e35eacec0c29db431a82d74743086a88743a4", null ],
      [ "SHORE_REPLACE_ACTION_A", "d4/d48/newgrf_8h.html#aae7e5011a054dadf96117e249a32e35ea295fac40dd9160c42495ebdc788bf497", null ],
      [ "SHORE_REPLACE_ONLY_NEW", "d4/d48/newgrf_8h.html#aae7e5011a054dadf96117e249a32e35eaa84c1bbf57e597b026de69e23779d94a", null ]
    ] ],
    [ "GetGlobalVariable", "d4/d48/newgrf_8h.html#a46951360727ca22fade6dd3b12c67ee9", null ],
    [ "GetGRFContainerVersion", "d4/d48/newgrf_8h.html#af43f55d0a2b588cdb8af7a0cecd439e4", null ],
    [ "grfmsg", "d4/d48/newgrf_8h.html#a504b9aeec087d2c5965ae85315310e2f", null ],
    [ "HasGrfMiscBit", "d4/d48/newgrf_8h.html#a10cb802fffa88bc15bcc0e7df594dd68", null ],
    [ "LoadNewGRF", "d4/d48/newgrf_8h.html#ab613c8412775aef6646ca1482e3bfbad", null ],
    [ "LoadNewGRFFile", "d4/d48/newgrf_8h.html#ad963f969ccb61b9cbbc24f27aa3c08e6", null ],
    [ "MapGRFStringID", "d4/d48/newgrf_8h.html#adbc049a4a1345b7829fad5feefaae1de", null ],
    [ "ReloadNewGRFData", "d4/d48/newgrf_8h.html#ae1e0636735fd3dcc31c89a82b84394d8", null ],
    [ "ResetNewGRFData", "d4/d48/newgrf_8h.html#a99c779588222d1f09354a4f0eb97bfb7", null ],
    [ "ResetPersistentNewGRFData", "d4/d48/newgrf_8h.html#a17c5cb3e25b7197941b68e89f8ff938b", null ],
    [ "ShowNewGRFError", "d4/d48/newgrf_8h.html#ade76f8fb8e0bc2d24d03b10418ee6676", null ],
    [ "_loaded_newgrf_features", "d4/d48/newgrf_8h.html#a85d20a06044a2da946df03e28fcd6ef3", null ],
    [ "INVALID_GRFID", "d4/d48/newgrf_8h.html#a7184fb2d148626414c0f011865ebed11", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d4/d48/newgrf_8h.js <==
var newgrf_8h =
[
    [ "CanalProperties", "d7/df3/structCanalProperties.html", "d7/df3/structCanalProperties" ],
    [ "GRFLabel", "dc/d6c/structGRFLabel.html", "dc/d6c/structGRFLabel" ],
    [ "GRFFile", "d1/d53/structGRFFile.html", "d1/d53/structGRFFile" ],
    [ "GRFLoadedFeatures", "d5/dd5/structGRFLoadedFeatures.html", "d5/dd5/structGRFLoadedFeatures" ],
    [ "CanalFeature", "d4/d48/newgrf_8h.html#adbb765b5f83e5e13ed31c76be18fd933", [
      [ "CF_WATERSLOPE", "d4/d48/newgrf_8h.html#adbb765b5f83e5e13ed31c76be18fd933af8eaf6e247f3d19ab88618fbbd63dbee", null ],
      [ "CF_LOCKS", "d4/d48/newgrf_8h.html#adbb765b5f83e5e13ed31c76be18fd933a5a57741888ffe2d2a40e15a5a6b96477", null ],
      [ "CF_DIKES", "d4/d48/newgrf_8h.html#adbb765b5f83e5e13ed31c76be18fd933a0963ed28a64ef7a22f8c06bacf3a0eb0", null ],
      [ "CF_ICON", "d4/d48/newgrf_8h.html#adbb765b5f83e5e13ed31c76be18fd933ace384691a568d66d0907d03fb6c77873", null ],
      [ "CF_DOCKS", "d4/d48/newgrf_8h.html#adbb765b5f83e5e13ed31c76be18fd933afa2d4cb8f1932cb5557504bad2810804", null ],
      [ "CF_RIVER_SLOPE", "d4/d48/newgrf_8h.html#adbb765b5f83e5e13ed31c76be18fd933a5d203eb15f1dce708cbe72b100802e0d", null ],
      [ "CF_RIVER_EDGE", "d4/d48/newgrf_8h.html#adbb765b5f83e5e13ed31c76be18fd933aa7819b842480d4eb2de4853c8c1b692b", null ],
      [ "CF_RIVER_GUI", "d4/d48/newgrf_8h.html#adbb765b5f83e5e13ed31c76be18fd933a0e55e0320e2146f943a6296689eb4628", null ],
      [ "CF_BUOY", "d4/d48/newgrf_8h.html#adbb765b5f83e5e13ed31c76be18fd933a2d90ce24edcf0ef51a42afb1a21b578f", null ],
      [ "CF_END", "d4/d48/newgrf_8h.html#adbb765b5f83e5e13ed31c76be18fd933a095e0dd0731658557edfd9261560f541", null ]
    ] ],
    [ "GrfLoadingStage", "d4/d48/newgrf_8h.html#ae7d82234c394971067394d5d3516dfc8", [
      [ "GLS_FILESCAN", "d4/d48/newgrf_8h.html#ae7d82234c394971067394d5d3516dfc8a3f4b9e3a44fb1f1c87126a42f2d9ff2b", null ],
      [ "GLS_SAFETYSCAN", "d4/d48/newgrf_8h.html#ae7d82234c394971067394d5d3516dfc8af52a20b0eee00a99d034825409081c0c", null ],
      [ "GLS_LABELSCAN", "d4/d48/newgrf_8h.html#ae7d82234c394971067394d5d3516dfc8abf73201c5e2a615fbeed18259cd07ce8", null ],
      [ "GLS_INIT", "d4/d48/newgrf_8h.html#ae7d82234c394971067394d5d3516dfc8a80ece95b1919a116e75f31e1a4fc5e60", null ],
      [ "GLS_RESERVE", "d4/d48/newgrf_8h.html#ae7d82234c394971067394d5d3516dfc8a73d61f963e5cbd790f8bbe8ab3bbba8f", null ],
      [ "GLS_ACTIVATION", "d4/d48/newgrf_8h.html#ae7d82234c394971067394d5d3516dfc8aedf7b2b921e815966b128e51608fd33e", null ],
      [ "GLS_END", "d4/d48/newgrf_8h.html#ae7d82234c394971067394d5d3516dfc8a7cf74d6696946f982bbfbcb6bba71b5d", null ]
    ] ],
    [ "GrfMiscBit", "d4/d48/newgrf_8h.html#a7f005440c7ec2678300d41df0eb71f8f", [
      [ "GMB_DESERT_TREES_FIELDS", "d4/d48/newgrf_8h.html#a7f005440c7ec2678300d41df0eb71f8faccdf068d8e2d46f19bda7f1c8b85d084", null ],
      [ "GMB_DESERT_PAVED_ROADS", "d4/d48/newgrf_8h.html#a7f005440c7ec2678300d41df0eb71f8fa3f6c7a31f7d335390451af69de8350b6", null ],
      [ "GMB_FIELD_BOUNDING_BOX", "d4/d48/newgrf_8h.html#a7f005440c7ec2678300d41df0eb71f8fa9a19cd99c699437f375ed1479fe4fa35", null ],
      [ "GMB_TRAIN_WIDTH_32_PIXELS", "d4/d48/newgrf_8h.html#a7f005440c7ec2678300d41df0eb71f8fae21984bb6385d9e64c97b1419ace4d57", null ],
      [ "GMB_AMBIENT_SOUND_CALLBACK", "d4/d48/newgrf_8h.html#a7f005440c7ec2678300d41df0eb71f8fa519e147f5a0d92d67d11c06281979463", null ],
      [ "GMB_CATENARY_ON_3RD_TRACK", "d4/d48/newgrf_8h.html#a7f005440c7ec2678300d41df0eb71f8fa9bad51a17380a81999d9c8b70c858b5f", null ],
      [ "GMB_SECOND_ROCKY_TILE_SET", "d4/d48/newgrf_8h.html#a7f005440c7ec2678300d41df0eb71f8fa822d70038b1d7ccefea5af8f74e06695", null ]
    ] ],
    [ "GrfSpecFeature", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71fed", [
      [ "GSF_TRAINS", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71feda26df69171fb034ed3cf892bc4daa8fac", null ],
      [ "GSF_ROADVEHICLES", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71feda755d310e70804a736e47453e258f7c0e", null ],
      [ "GSF_SHIPS", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71feda7076c36d72deb69536d404605a1cac67", null ],
      [ "GSF_AIRCRAFT", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71fedaa33d020de9a1390c5553f74a912277b9", null ],
      [ "GSF_STATIONS", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71feda0609a53393335363693c183b3375966d", null ],
      [ "GSF_CANALS", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71feda69e99804291f7504d05e218d4268d9c9", null ],
      [ "GSF_BRIDGES", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71feda4f63e02c0e3e15630447e928881e7b41", null ],
      [ "GSF_HOUSES", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71feda06011824707bd88351a7471eaefb5cbb", null ],
      [ "GSF_GLOBALVAR", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71feda04eeda295e3b6b7c8ba8a861b06044df", null ],
      [ "GSF_INDUSTRYTILES", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71fedaa6adfbbf866f6f92622eddca16306507", null ],
      [ "GSF_INDUSTRIES", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71fedac1d6d9cf5b9176a997ac2a4641caabf1", null ],
      [ "GSF_CARGOES", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71feda5b78c9caf284955b01f03b7cb4c53320", null ],
      [ "GSF_SOUNDFX", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71fedaab0857a902a10d5b93bc77923adc09a0", null ],
      [ "GSF_AIRPORTS", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71feda42af615d90c798d00f84af49c8ae5309", null ],
      [ "GSF_SIGNALS", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71fedaaabc57449adf973e52a19ed04649bf01", null ],
      [ "GSF_OBJECTS", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71feda50f206bf98e3d7058965458bac7a27ad", null ],
      [ "GSF_RAILTYPES", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71fedaee99c5670b3b404fd8f94b30a731fef6", null ],
      [ "GSF_AIRPORTTILES", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71feda4bf75eab552b66ea5e534d043797b180", null ],
      [ "GSF_ROADTYPES", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71feda1ebe26a0c99abf2c8c0f2a020d3005c1", null ],
      [ "GSF_TRAMTYPES", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71fedac69441d282221ea0c9cf117c47d8a9a0", null ],
      [ "GSF_END", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71feda2ac469a0cb96ec26a646f017a3151119", null ],
      [ "GSF_FAKE_TOWNS", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71feda2e5f12fce01460a62a2060acc3817ded", null ],
      [ "GSF_FAKE_END", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71fedab4f65c0c10aa7156c5b1b70d0d836173", null ],
      [ "GSF_INVALID", "d4/d48/newgrf_8h.html#a2465e74e21d7ce15bba8094d7de71fedab1911de5bda9645ec61bbe15b46b7d49", null ]
    ] ],
    [ "ShoreReplacement", "d4/d48/newgrf_8h.html#aae7e5011a054dadf96117e249a32e35e", [
      [ "SHORE_REPLACE_NONE", "d4/d48/newgrf_8h.html#aae7e5011a054dadf96117e249a32e35ea85983d6b8e72b2318260af67ba75a5f2", null ],
      [ "SHORE_REPLACE_ACTION_5", "d4/d48/newgrf_8h.html#aae7e5011a054dadf96117e249a32e35eacec0c29db431a82d74743086a88743a4", null ],
      [ "SHORE_REPLACE_ACTION_A", "d4/d48/newgrf_8h.html#aae7e5011a054dadf96117e249a32e35ea295fac40dd9160c42495ebdc788bf497", null ],
      [ "SHORE_REPLACE_ONLY_NEW", "d4/d48/newgrf_8h.html#aae7e5011a054dadf96117e249a32e35eaa84c1bbf57e597b026de69e23779d94a", null ]
    ] ],
    [ "TramReplacement", "d4/d48/newgrf_8h.html#a9d5885d992617e782c781b9c575df08b", [
      [ "TRAMWAY_REPLACE_DEPOT_NONE", "d4/d48/newgrf_8h.html#a9d5885d992617e782c781b9c575df08bad25a6780d4571ad3b52140b5198d5145", null ],
      [ "TRAMWAY_REPLACE_DEPOT_WITH_TRACK", "d4/d48/newgrf_8h.html#a9d5885d992617e782c781b9c575df08ba2bcdae2fd22bcdd5345842dc8a38279d", null ],
      [ "TRAMWAY_REPLACE_DEPOT_NO_TRACK", "d4/d48/newgrf_8h.html#a9d5885d992617e782c781b9c575df08bac092b062e097bfc1421b84f3930d5504", null ]
    ] ],
    [ "GetGlobalVariable", "d4/d48/newgrf_8h.html#a46951360727ca22fade6dd3b12c67ee9", null ],
    [ "GetGRFContainerVersion", "d4/d48/newgrf_8h.html#af43f55d0a2b588cdb8af7a0cecd439e4", null ],
    [ "grfmsg", "d4/d48/newgrf_8h.html#a504b9aeec087d2c5965ae85315310e2f", null ],
    [ "HasGrfMiscBit", "d4/d48/newgrf_8h.html#a10cb802fffa88bc15bcc0e7df594dd68", null ],
    [ "LoadNewGRF", "d4/d48/newgrf_8h.html#ab613c8412775aef6646ca1482e3bfbad", null ],
    [ "LoadNewGRFFile", "d4/d48/newgrf_8h.html#ad963f969ccb61b9cbbc24f27aa3c08e6", null ],
    [ "MapGRFStringID", "d4/d48/newgrf_8h.html#adbc049a4a1345b7829fad5feefaae1de", null ],
    [ "ReloadNewGRFData", "d4/d48/newgrf_8h.html#ae1e0636735fd3dcc31c89a82b84394d8", null ],
    [ "ResetNewGRFData", "d4/d48/newgrf_8h.html#a99c779588222d1f09354a4f0eb97bfb7", null ],
    [ "ResetPersistentNewGRFData", "d4/d48/newgrf_8h.html#a17c5cb3e25b7197941b68e89f8ff938b", null ],
    [ "ShowNewGRFError", "d4/d48/newgrf_8h.html#ade76f8fb8e0bc2d24d03b10418ee6676", null ],
    [ "_loaded_newgrf_features", "d4/d48/newgrf_8h.html#a85d20a06044a2da946df03e28fcd6ef3", null ],
    [ "INVALID_GRFID", "d4/d48/newgrf_8h.html#a7184fb2d148626414c0f011865ebed11", null ]
];
